aboutsummaryrefslogtreecommitdiffstats
path: root/drivers/gdisp/SSD1289/gdisp_lld_board_example.h
diff options
context:
space:
mode:
authorAndrew Hannam <andrewh@inmarket.com.au>2012-11-25 22:44:25 -0800
committerAndrew Hannam <andrewh@inmarket.com.au>2012-11-25 22:44:25 -0800
commit6cc2bc280cc7dc4cb546d94219210d65c15df2e1 (patch)
tree54b4ded1928d9f03d74b74aefe333cc93f047ba9 /drivers/gdisp/SSD1289/gdisp_lld_board_example.h
parentd1836d49fee08eaa08a837e9f6176f3d41fbb735 (diff)
parentac5267af6af5508d4391fddb3d27c8d45879950a (diff)
downloaduGFX-6cc2bc280cc7dc4cb546d94219210d65c15df2e1.tar.gz
uGFX-6cc2bc280cc7dc4cb546d94219210d65c15df2e1.tar.bz2
uGFX-6cc2bc280cc7dc4cb546d94219210d65c15df2e1.zip
Merge pull request #8 from Tectu/master
Merge Tectu Changes
Diffstat (limited to 'drivers/gdisp/SSD1289/gdisp_lld_board_example.h')
-rw-r--r--drivers/gdisp/SSD1289/gdisp_lld_board_example.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/drivers/gdisp/SSD1289/gdisp_lld_board_example.h b/drivers/gdisp/SSD1289/gdisp_lld_board_example.h
index 6dcad1b5..c47a6ed6 100644
--- a/drivers/gdisp/SSD1289/gdisp_lld_board_example.h
+++ b/drivers/gdisp/SSD1289/gdisp_lld_board_example.h
@@ -68,8 +68,8 @@ static __inline void set_backlight(uint8_t percent) {
*
* @notapi
*/
-static __inline void get_bus(void) {
-#error "SSD1289: You must supply a definition for get_bus for your board"
+static __inline void acquire_bus(void) {
+#error "SSD1289: You must supply a definition for acquire_bus for your board"
}
/**